@@ -23,41 +23,11 @@ class AddCdnDomainRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'AddCdnDomain')
 
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
+	def get_TopLevelDomain(self):
+		return self.get_query_params().get('TopLevelDomain')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_OwnerAccount(self):
-		return self.get_query_params().get('OwnerAccount')
-
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_DomainName(self):
-		return self.get_query_params().get('DomainName')
-
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_CdnType(self):
-		return self.get_query_params().get('CdnType')
-
-	def set_CdnType(self,CdnType):
-		self.add_query_param('CdnType',CdnType)
-
-	def get_SourceType(self):
-		return self.get_query_params().get('SourceType')
-
-	def set_SourceType(self,SourceType):
-		self.add_query_param('SourceType',SourceType)
+	def set_TopLevelDomain(self,TopLevelDomain):
+		self.add_query_param('TopLevelDomain',TopLevelDomain)
 
 	def get_Sources(self):
 		return self.get_query_params().get('Sources')
@@ -65,20 +35,80 @@ class AddCdnDomainRequest(RpcRequest):
 	def set_Sources(self,Sources):
 		self.add_query_param('Sources',Sources)
 
+	def get_OwnerAccount(self):
+		return self.get_query_params().get('OwnerAccount')
+
+	def set_OwnerAccount(self,OwnerAccount):
+		self.add_query_param('OwnerAccount',OwnerAccount)
+
+	def get_DomainName(self):
+		return self.get_query_params().get('DomainName')
+
+	def set_DomainName(self,DomainName):
+		self.add_query_param('DomainName',DomainName)
+
+	def get_LiveType(self):
+		return self.get_query_params().get('LiveType')
+
+	def set_LiveType(self,LiveType):
+		self.add_query_param('LiveType',LiveType)
+
+	def get_OwnerId(self):
+		return self.get_query_params().get('OwnerId')
+
+	def set_OwnerId(self,OwnerId):
+		self.add_query_param('OwnerId',OwnerId)
+
+	def get_ResourceGroupId(self):
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self,ResourceGroupId):
+		self.add_query_param('ResourceGroupId',ResourceGroupId)
+
 	def get_SourcePort(self):
 		return self.get_query_params().get('SourcePort')
 
 	def set_SourcePort(self,SourcePort):
 		self.add_query_param('SourcePort',SourcePort)
 
-	def get_ServerCertificate(self):
-		return self.get_query_params().get('ServerCertificate')
+	def get_Priorities(self):
+		return self.get_query_params().get('Priorities')
 
-	def set_ServerCertificate(self,ServerCertificate):
-		self.add_query_param('ServerCertificate',ServerCertificate)
+	def set_Priorities(self,Priorities):
+		self.add_query_param('Priorities',Priorities)
 
-	def get_PrivateKey(self):
-		return self.get_query_params().get('PrivateKey')
+	def get_SecurityToken(self):
+		return self.get_query_params().get('SecurityToken')
 
-	def set_PrivateKey(self,PrivateKey):
-		self.add_query_param('PrivateKey',PrivateKey)
\ No newline at end of file
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
+
+	def get_CdnType(self):
+		return self.get_query_params().get('CdnType')
+
+	def set_CdnType(self,CdnType):
+		self.add_query_param('CdnType',CdnType)
+
+	def get_Scope(self):
+		return self.get_query_params().get('Scope')
+
+	def set_Scope(self,Scope):
+		self.add_query_param('Scope',Scope)
+
+	def get_SourceType(self):
+		return self.get_query_params().get('SourceType')
+
+	def set_SourceType(self,SourceType):
+		self.add_query_param('SourceType',SourceType)
+
+	def get_CheckUrl(self):
+		return self.get_query_params().get('CheckUrl')
+
+	def set_CheckUrl(self,CheckUrl):
+		self.add_query_param('CheckUrl',CheckUrl)
+
+	def get_Region(self):
+		return self.get_query_params().get('Region')
+
+	def set_Region(self,Region):
+		self.add_query_param('Region',Region)
\ No newline at end of file
