@@ -23,29 +23,17 @@ class DescribeUserDomainsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'DescribeUserDomains')
 
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
+	def get_FuncFilter(self):
+		return self.get_query_params().get('FuncFilter')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
+	def set_FuncFilter(self,FuncFilter):
+		self.add_query_param('FuncFilter',FuncFilter)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
+	def get_Sources(self):
+		return self.get_query_params().get('Sources')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_PageSize(self):
-		return self.get_query_params().get('PageSize')
-
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_PageNumber(self):
-		return self.get_query_params().get('PageNumber')
-
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
+	def set_Sources(self,Sources):
+		self.add_query_param('Sources',Sources)
 
 	def get_DomainName(self):
 		return self.get_query_params().get('DomainName')
@@ -53,6 +41,24 @@ class DescribeUserDomainsRequest(RpcRequest):
 	def set_DomainName(self,DomainName):
 		self.add_query_param('DomainName',DomainName)
 
+	def get_OwnerId(self):
+		return self.get_query_params().get('OwnerId')
+
+	def set_OwnerId(self,OwnerId):
+		self.add_query_param('OwnerId',OwnerId)
+
+	def get_FuncId(self):
+		return self.get_query_params().get('FuncId')
+
+	def set_FuncId(self,FuncId):
+		self.add_query_param('FuncId',FuncId)
+
+	def get_PageNumber(self):
+		return self.get_query_params().get('PageNumber')
+
+	def set_PageNumber(self,PageNumber):
+		self.add_query_param('PageNumber',PageNumber)
+
 	def get_DomainStatus(self):
 		return self.get_query_params().get('DomainStatus')
 
@@ -65,14 +71,32 @@ class DescribeUserDomainsRequest(RpcRequest):
 	def set_DomainSearchType(self,DomainSearchType):
 		self.add_query_param('DomainSearchType',DomainSearchType)
 
-	def get_Sources(self):
-		return self.get_query_params().get('Sources')
+	def get_CheckDomainShow(self):
+		return self.get_query_params().get('CheckDomainShow')
 
-	def set_Sources(self,Sources):
-		self.add_query_param('Sources',Sources)
+	def set_CheckDomainShow(self,CheckDomainShow):
+		self.add_query_param('CheckDomainShow',CheckDomainShow)
+
+	def get_ResourceGroupId(self):
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self,ResourceGroupId):
+		self.add_query_param('ResourceGroupId',ResourceGroupId)
+
+	def get_SecurityToken(self):
+		return self.get_query_params().get('SecurityToken')
+
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
 
 	def get_CdnType(self):
 		return self.get_query_params().get('CdnType')
 
 	def set_CdnType(self,CdnType):
-		self.add_query_param('CdnType',CdnType)
\ No newline at end of file
+		self.add_query_param('CdnType',CdnType)
+
+	def get_PageSize(self):
+		return self.get_query_params().get('PageSize')
+
+	def set_PageSize(self,PageSize):
+		self.add_query_param('PageSize',PageSize)
\ No newline at end of file
